==> cobalt-0.0.2-sources.jar: it/auties/whatsapp/model/companion/CompanionSyncKeySpec.java <==
package it.auties.whatsapp.model.companion;

import it.auties.whatsapp.model.companion.CompanionSyncKey;
import it.auties.protobuf.stream.ProtobufInputStream;
import it.auties.protobuf.stream.ProtobufOutputStream;

public class CompanionSyncKeySpec {
    public static byte[] encode(CompanionSyncKey protoInputObject) {
      if(protoInputObject == null) {
         return null;
      }
      var outputStream = new ProtobufOutputStream();
var companion = protoInputObject.companion();
if(companion != null) {
var companion0 = companion.toProtobufValue();
if(companion0 != null) {
outputStream.writeString(1, companion0);
}
}
      if(protoInputObject.keys() != null) {
       for(var keysEntry : protoInputObject.keys()) {
outputStream.writeBytes(2, it.auties.whatsapp.model.sync.AppStateSyncKeySpec.encode(keysEntry));
       }
      }
      return outputStream.toByteArray();
    }

    public static CompanionSyncKey decode(byte[] input) {
        if(input == null) {
            return null;
        }
        var inputStream = new ProtobufInputStream(input);
        it.auties.whatsapp.model.jid.Jid companion = null;
        java.util.LinkedList<it.auties.whatsapp.model.sync.AppStateSyncKey> keys = new java.util.LinkedList<it.auties.whatsapp.model.sync.AppStateSyncKey>();
        while(inputStream.readTag()) {
            switch(inputStream.index()) {
                case 1 -> companion = it.auties.whatsapp.model.jid.Jid.ofProtobuf(inputStream.readString());
                case 2 -> keys.add(it.auties.whatsapp.model.sync.AppStateSyncKeySpec.decode(inputStream.readBytes()));
                default -> inputStream.skipBytes();
            }
        }
        return new it.auties.whatsapp.model.companion.CompanionSyncKey(companion, keys);
    }

}

==> cobalt-0.0.4-sources.jar: it/auties/whatsapp/model/companion/CompanionSyncKeySpec.java <==
package it.auties.whatsapp.model.companion;

import it.auties.whatsapp.model.companion.CompanionSyncKey;
import it.auties.protobuf.stream.ProtobufInputStream;
import it.auties.protobuf.stream.ProtobufOutputStream;

public class CompanionSyncKeySpec {
    public static byte[] encode(CompanionSyncKey protoInputObject) {
      if(protoInputObject == null) {
         return null;
      }
      var outputStream = new ProtobufOutputStream();
var companion = protoInputObject.companion();
if(companion != null) {
var companion0 = companion.toString();
if(companion0 != null) {
outputStream.writeString(1, companion0);
}
}
      if(protoInputObject.keys() != null) {
       for(var keysEntry : protoInputObject.keys()) {
outputStream.writeBytes(2, it.auties.whatsapp.model.sync.AppStateSyncKeySpec.encode(keysEntry));
       }
      }
      return outputStream.toByteArray();
    }

    public static CompanionSyncKey decode(byte[] input) {
        if(input == null) {
            return null;
        }
        var inputStream = new ProtobufInputStream(input);
        it.auties.whatsapp.model.jid.Jid companion = null;
        java.util.LinkedList<it.auties.whatsapp.model.sync.AppStateSyncKey> keys = new java.util.LinkedList<it.auties.whatsapp.model.sync.AppStateSyncKey>();
        while(inputStream.readTag()) {
            switch(inputStream.index()) {
                case 1 -> companion = it.auties.whatsapp.model.jid.Jid.ofProtobuf(inputStream.readString());
                case 2 -> keys.add(it.auties.whatsapp.model.sync.AppStateSyncKeySpec.decode(inputStream.readBytes()));
                default -> inputStream.skipBytes();
            }
        }
        return new it.auties.whatsapp.model.companion.CompanionSyncKey(companion, keys);
    }

}
